
# EBBEF2p for Python

[![PyPI version](https://badge.fury.io/py/ebbef2p-python.svg)](https://badge.fury.io/py/ebbef2p-python)
[![GitHub license](https://img.shields.io/github/license/bteodoru/ebbef2p-python)](https://github.com/bteodoru/ebbef2p-python/blob/master/LICENSE)
[![Documentation Status](https://readthedocs.org/projects/ebbef2p-python/badge/?version=latest)](https://ebbef2p-python.readthedocs.io/en/latest/?badge=latest)
## Background

The computer program EBBEF2p was originally written as a toolbox for the MATLAB computing environment. EBBEF2p (Euler-Bernoulli Beams on Two-Parameter Elastic Foundationis) can handle a wide range of static loading problems involving one-dimensional beams supported by elastic foundation.

## Why EBBEF2p for Python?
Matlab is a quite expensive comercial product, which means that code that is written in Matlab can only be used by people with sufficient funds to buy a license. Unlike MATLAB, Python is free to use and distribute both for personal and commercial use.
